@@ -15,7 +15,7 @@ struct VocabularyDb;
 
 class PresetVocabulary {
  public:
-  PresetVocabulary();
+  explicit PresetVocabulary(const string& vocabulary);
   ~PresetVocabulary();
 
   // random access
@@ -29,7 +29,7 @@ class PresetVocabulary {
   void set_max_phrase_length(int length) { max_phrase_length_ = length; }
   void set_min_phrase_weight(double weight) { min_phrase_weight_ = weight; }
 
-  static string DictFilePath();
+  static string DictFilePath(const string& vacabulary);
 
  protected:
   the<VocabularyDb> db_;
