@@ -41,7 +41,8 @@ ProcessResult ShapeProcessor::ProcessKeyEvent(const KeyEvent& key_event) {
   if (!engine_->context()->get_option("full_shape")) {
     return kNoop;
   }
-  if (key_event.ctrl() || key_event.alt() || key_event.release()) {
+  if (key_event.ctrl() || key_event.alt() || key_event.super() ||
+      key_event.release()) {
     return kNoop;
   }
   int ch = key_event.keycode();
