@@ -6,6 +6,7 @@
 //
 #include <boost/algorithm/string.hpp>
 #include <boost/range/adaptor/reversed.hpp>
+#include <cmath>
 #include <utf8.h>
 #include <rime/candidate.h>
 #include <rime/common.h>
@@ -80,10 +81,10 @@ an<Candidate> TableTranslation::Peek() {
   if (phrase) {
     phrase->set_comment(comment);
     phrase->set_preedit(preedit_);
-    phrase->set_quality(exp(e->weight) +
-                        options_->initial_quality() +
-                        (incomplete ? -1 : 0) +
-                        (is_user_phrase ? 0.5 : 0));
+    phrase->set_quality(std::exp(e->weight) +
+                       options_->initial_quality() +
+                       (incomplete ? -1 : 0) +
+                       (is_user_phrase ? 0.5 : 0));
   }
   return phrase;
 }
