@@ -20,29 +20,15 @@
 #include <rime/service.h>
 #include <rime/setup.h>
 #include <rime/signature.h>
+#include <rime/switches.h>
 #include <rime_api.h>
 
 using namespace rime;
 using namespace std::placeholders;
 
-// assuming member is a pointer in struct *p
+// assume member is a non-null pointer in struct *p.
 #define PROVIDED(p, member) ((p) && RIME_STRUCT_HAS_MEMBER(*(p), (p)->member) && (p)->member)
 
-static void setup_deployer(RimeTraits *traits) {
-  if (!traits) return;
-  Deployer &deployer(Service::instance().deployer());
-  if (PROVIDED(traits, shared_data_dir))
-    deployer.shared_data_dir = traits->shared_data_dir;
-  if (PROVIDED(traits, user_data_dir))
-    deployer.user_data_dir = traits->user_data_dir;
-  if (PROVIDED(traits, distribution_name))
-    deployer.distribution_name = traits->distribution_name;
-  if (PROVIDED(traits, distribution_code_name))
-    deployer.distribution_code_name = traits->distribution_code_name;
-  if (PROVIDED(traits, distribution_version))
-    deployer.distribution_version = traits->distribution_version;
-}
-
 RIME_API void RimeSetupLogging(const char* app_name) {
   SetupLogging(app_name);
 }
@@ -66,9 +52,14 @@ static void rime_declare_module_dependencies() {
 RIME_API void RimeSetup(RimeTraits *traits) {
   rime_declare_module_dependencies();
 
-  setup_deployer(traits);
+  SetupDeployer(traits);
   if (PROVIDED(traits, app_name)) {
-    SetupLogging(traits->app_name);
+    if (RIME_STRUCT_HAS_MEMBER(*traits, traits->min_log_level) &&
+        RIME_STRUCT_HAS_MEMBER(*traits, traits->log_dir)) {
+      SetupLogging(traits->app_name, traits->min_log_level, traits->log_dir);
+    } else {
+      SetupLogging(traits->app_name);
+    }
   }
 }
 
@@ -84,7 +75,7 @@ RIME_API void RimeSetNotificationHandler(RimeNotificationHandler handler,
 }
 
 RIME_API void RimeInitialize(RimeTraits *traits) {
-  setup_deployer(traits);
+  SetupDeployer(traits);
   LoadModules(PROVIDED(traits, modules) ? traits->modules : kDefaultModules);
   Service::instance().StartService();
 }
@@ -105,7 +96,10 @@ RIME_API Bool RimeStartMaintenance(Bool full_check) {
   }
   if (!full_check) {
     TaskInitializer args{
-      vector<string>{deployer.user_data_dir, deployer.shared_data_dir}
+      vector<string>{
+        deployer.user_data_dir,
+        deployer.shared_data_dir,
+      },
     };
     if (!deployer.RunTask("detect_modifications", args)) {
       return False;
@@ -136,7 +130,7 @@ RIME_API void RimeJoinMaintenanceThread() {
 // deployment
 
 RIME_API void RimeDeployerInitialize(RimeTraits *traits) {
-  setup_deployer(traits);
+  SetupDeployer(traits);
   LoadModules(PROVIDED(traits, modules) ? traits->modules : kDeployerModules);
 }
 
@@ -329,7 +323,7 @@ RIME_API Bool RimeFreeContext(RimeContext* context) {
 }
 
 RIME_API Bool RimeGetCommit(RimeSessionId session_id, RimeCommit* commit) {
-  if (!commit)
+    if (!commit)
     return False;
   RIME_STRUCT_CLEAR(*commit);
   an<Session> session(Service::instance().GetSession(session_id));
@@ -354,7 +348,7 @@ RIME_API Bool RimeFreeCommit(RimeCommit* commit) {
 }
 
 RIME_API Bool RimeGetStatus(RimeSessionId session_id, RimeStatus* status) {
-  if (!status || status->data_size <= 0)
+    if (!status || status->data_size <= 0)
     return False;
   RIME_STRUCT_CLEAR(*status);
   an<Session> session(Service::instance().GetSession(session_id));
@@ -777,6 +771,16 @@ RIME_API const char* RimeGetUserDataDir() {
   return deployer.user_data_dir.c_str();
 }
 
+RIME_API const char* RimeGetPrebuiltDataDir() {
+  Deployer &deployer(Service::instance().deployer());
+  return deployer.prebuilt_data_dir.c_str();
+}
+
+RIME_API const char* RimeGetStagingDir() {
+  Deployer &deployer(Service::instance().deployer());
+  return deployer.staging_dir.c_str();
+}
+
 RIME_API const char* RimeGetSyncDir() {
   Deployer &deployer(Service::instance().deployer());
   return deployer.sync_dir.c_str();
@@ -935,38 +939,59 @@ size_t RimeGetCaretPos(RimeSessionId session_id) {
   return ctx->caret_pos();
 }
 
-Bool RimeSelectCandidate(RimeSessionId session_id, size_t index) {
+static bool do_with_candidate(RimeSessionId session_id, size_t index,
+                              bool (Context::* verb)(size_t index)) {
   an<Session> session(Service::instance().GetSession(session_id));
   if (!session)
-    return False;
-  Context *ctx = session->context();
-  if (!ctx)
-    return False;
-  return Bool(ctx->Select(index));
+        return False;
+    Context *ctx = session->context();
+    if (!ctx)
+        return False;
+    return (ctx->*verb)(index);
+}
+
+static bool do_with_candidate_on_current_page(
+    RimeSessionId session_id, size_t index,
+    bool (Context::* verb)(size_t index)) {
+  an<Session> session(Service::instance().GetSession(session_id));
+  if (!session)
+        return False;
+    Context *ctx = session->context();
+    if (!ctx || !ctx->HasMenu())
+        return False;
+    Schema *schema = session->schema();
+    if (!schema)
+        return False;
+    size_t page_size = (size_t)schema->page_size();
+    if (index >= page_size)
+        return False;
+    const auto& seg(ctx->composition().back());
+    size_t page_start = seg.selected_index / page_size * page_size;
+    return (ctx->*verb)(page_start + index);
+}
+
+
+Bool RimeSelectCandidate(RimeSessionId session_id, size_t index) {
+  return do_with_candidate(session_id, index, &Context::Select);
 }
 
 Bool RimeSelectCandidateOnCurrentPage(RimeSessionId session_id, size_t index) {
-  an<Session> session(Service::instance().GetSession(session_id));
-  if (!session)
-    return False;
-  Context *ctx = session->context();
-  if (!ctx || !ctx->HasMenu())
-    return False;
-  Schema *schema = session->schema();
-  if (!schema)
-    return False;
-  size_t page_size = (size_t)schema->page_size();
-  if (index >= page_size)
-    return False;
-  const auto& seg(ctx->composition().back());
-  size_t page_start = seg.selected_index / page_size * page_size;
-  return Bool(ctx->Select(page_start + index));
+  return do_with_candidate_on_current_page(session_id, index, &Context::Select);
 }
 
 const char* RimeGetVersion() {
   return RIME_VERSION;
 }
 
+Bool RimeDeleteCandidate(RimeSessionId session_id, size_t index) {
+  return do_with_candidate(session_id, index, &Context::DeleteCandidate);
+}
+
+Bool RimeDeleteCandidateOnCurrentPage(RimeSessionId session_id, size_t index) {
+  return do_with_candidate_on_current_page(
+      session_id, index, &Context::DeleteCandidate);
+}
+
 void RimeSetCaretPos(RimeSessionId session_id, size_t caret_pos) {
   an<Session> session(Service::instance().GetSession(session_id));
   if (!session)
@@ -977,6 +1002,20 @@ void RimeSetCaretPos(RimeSessionId session_id, size_t caret_pos) {
   return ctx->set_caret_pos(caret_pos);
 }
 
+const char* RimeGetStateLabel(RimeSessionId session_id,
+                              const char* option_name,
+                              Bool state) {
+  an<Session> session(Service::instance().GetSession(session_id));
+  if (!session)
+    return nullptr;
+  Config* config = session->schema()->config();
+  if (!config)
+    return nullptr;
+  Switches switches(config);
+  an<ConfigValue> label = switches.GetStateLabel(option_name, state);
+  return label ? label->str().c_str() : nullptr;
+}
+
 RIME_API RimeApi* rime_get_api() {
   static RimeApi s_api = {0};
   if (!s_api.data_size) {
@@ -1061,6 +1100,14 @@ RIME_API RimeApi* rime_get_api() {
     s_api.candidate_list_next = &RimeCandidateListNext;
     s_api.candidate_list_end = &RimeCandidateListEnd;
     s_api.candidate_list_from_index = &RimeCandidateListFromIndex;
+    s_api.get_prebuilt_data_dir = &RimeGetPrebuiltDataDir;
+    s_api.get_staging_dir = &RimeGetStagingDir;
+    s_api.commit_proto = nullptr;
+    s_api.context_proto = nullptr;
+    s_api.status_proto = nullptr;
+    s_api.get_state_label = &RimeGetStateLabel;
+    s_api.delete_candidate = &RimeDeleteCandidate;
+    s_api.delete_candidate_on_current_page = &RimeDeleteCandidateOnCurrentPage;
   }
   return &s_api;
 }
